@@ -388,8 +388,10 @@ class CreateRecTaskRequest(AbstractModel):
         :type FilterModal: int
         :param EmotionalEnergy: 情绪能量值，取值为音量分贝值/10。取值范围：[1,10]。值越高情绪越强烈。0:不开启，1:开启
         :type EmotionalEnergy: int
-        :param ReinforceHotword: 热词增强功能。1:开启后（仅支持8k_zh,16k_zh），将开启同音替换功能，同音字、词在热词中配置。举例：热词配置“蜜制”并开启增强功能后，与“蜜制”同拼音（mizhi）的“秘制”、“蜜汁”的识别结果会被强制替换成“蜜制”。因此建议客户根据自己的实际情况开启该功能。
+        :param ReinforceHotword: 热词增强功能。1:开启后（仅支持8k_zh,16k_zh），将开启同音替换功能，同音字、词在热词中配置。举例：热词配置“蜜制”并开启增强功能后，与“蜜制”同拼音（mizhi）的“秘制”的识别结果会被强制替换成“蜜制”。因此建议客户根据自己的实际情况开启该功能。
         :type ReinforceHotword: int
+        :param SentenceMaxLength: 单标点最多字数，取值范围：[6，40]。默认为0，不开启该功能。该参数可用于字幕生成场景，控制单行字幕最大字数。
+        :type SentenceMaxLength: int
         """
         self.EngineModelType = None
         self.ChannelNum = None
@@ -410,6 +412,7 @@ class CreateRecTaskRequest(AbstractModel):
         self.FilterModal = None
         self.EmotionalEnergy = None
         self.ReinforceHotword = None
+        self.SentenceMaxLength = None
 
 
     def _deserialize(self, params):
@@ -432,6 +435,7 @@ class CreateRecTaskRequest(AbstractModel):
         self.FilterModal = params.get("FilterModal")
         self.EmotionalEnergy = params.get("EmotionalEnergy")
         self.ReinforceHotword = params.get("ReinforceHotword")
+        self.SentenceMaxLength = params.get("SentenceMaxLength")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
