@@ -335,6 +335,35 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateFlowSignUrl(self, request):
+        """创建签署链接，需要联系运营人员开白后才可使用
+
+        :param request: Request instance for CreateFlowSignUrl.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreateFlowSignUrlRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreateFlowSignUrlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateFlowSignUrl", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateFlowSignUrlResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateIntegrationEmployees(self, request):
         """创建员工
 
