@@ -53,6 +53,9 @@ FAILEDOPERATION_DELETEUSERFAILED = 'FailedOperation.DeleteUserFailed'
 # 解绑安全组失败。
 FAILEDOPERATION_DISASSOCIATESECURITYGROUPSFAILED = 'FailedOperation.DisassociateSecurityGroupsFailed'
 
+# 拉取安全组详情失败。
+FAILEDOPERATION_GETSECURITYGROUPDETAILFAILED = 'FailedOperation.GetSecurityGroupDetailFailed'
+
 # 实例不可退费。
 FAILEDOPERATION_INSTANCECANNOTRETURN = 'FailedOperation.InstanceCanNotReturn'
 
@@ -62,6 +65,9 @@ FAILEDOPERATION_INSTANCERETURNFAILED = 'FailedOperation.InstanceReturnFailed'
 # 修改账号权限失败。
 FAILEDOPERATION_MODIFYRIGHTFAILED = 'FailedOperation.ModifyRightFailed'
 
+# 隔离实例失败。
+FAILEDOPERATION_OSSISOLATEINSTANCEFAILED = 'FailedOperation.OssIsolateInstanceFailed'
+
 # 请求后端接口失败。
 FAILEDOPERATION_OSSOPERATIONFAILED = 'FailedOperation.OssOperationFailed'
 
@@ -77,6 +83,9 @@ FAILEDOPERATION_SGCHANGEVIP = 'FailedOperation.SGChangeVip'
 # 设置规则失败。
 FAILEDOPERATION_SETRULELOCATIONFAILED = 'FailedOperation.SetRuleLocationFailed'
 
+# 安全组规则下发失败。
+FAILEDOPERATION_SETSVCLOCATIONFAILED = 'FailedOperation.SetSvcLocationFailed'
+
 # 标签键值校验或鉴权失败。
 FAILEDOPERATION_TAGDRYRUNERROR = 'FailedOperation.TagDryRunError'
 
@@ -86,6 +95,9 @@ FAILEDOPERATION_TAGQUOTAEXCEEDLIMIT = 'FailedOperation.TagQuotaExceedLimit'
 # 实例安全组信息更新失败。
 FAILEDOPERATION_UPDATEINSTANCEINFOFAILED = 'FailedOperation.UpdateInstanceInfoFailed'
 
+# 用户未经鉴权。
+FAILEDOPERATION_USERNOTAUTHED = 'FailedOperation.UserNotAuthed'
+
 # VIP不能与之前一样。
 FAILEDOPERATION_VIPNOTCHANGE = 'FailedOperation.VipNotChange'
 
@@ -158,6 +170,9 @@ INTERNALERROR_GETTABLEINFOFAILED = 'InternalError.GetTableInfoFailed'
 # 获取账号列表失败。
 INTERNALERROR_GETUSERLISTFAILED = 'InternalError.GetUserListFailed'
 
+# 获取用户安全组数量失败。
+INTERNALERROR_GETUSERSGCOUNTFAILED = 'InternalError.GetUserSGCountFailed'
+
 # 获取用户安全组配额失败。
 INTERNALERROR_GETUSGQUOTAERROR = 'InternalError.GetUsgQuotaError'
 
@@ -338,6 +353,9 @@ INVALIDPARAMETERVALUE_SPECIDILLEGAL = 'InvalidParameterValue.SpecIdIllegal'
 # 系统用户不允许操作。
 INVALIDPARAMETERVALUE_SUPERUSERFORBIDDEN = 'InvalidParameterValue.SuperUserForbidden'
 
+# 当前部署方式不允许设置此同步模式。
+INVALIDPARAMETERVALUE_SYNCMODENOTALLOWED = 'InvalidParameterValue.SyncModeNotAllowed'
+
 # 请求过于频繁。
 LIMITEXCEEDED_TOOFREQUENTLYCALLED = 'LimitExceeded.TooFrequentlyCalled'
 
@@ -394,3 +412,6 @@ UNSUPPORTEDOPERATION_INVALIDOPERATION = 'UnsupportedOperation.InvalidOperation'
 
 # Proxy软件版本太旧，请联系客服升级到新版本后再试。
 UNSUPPORTEDOPERATION_OLDPROXYVERSION = 'UnsupportedOperation.OldProxyVersion'
+
+# 不适用的操作。
+UNSUPPORTEDOPERATION_OPERATIONNOTAPPLICABLE = 'UnsupportedOperation.OperationNotApplicable'
