@@ -26,6 +26,64 @@ class SsmClient(AbstractClient):
     _service = 'ssm'
 
 
+    def CreateProductSecret(self, request):
+        """创建云产品凭据
+
+        :param request: Request instance for CreateProductSecret.
+        :type request: :class:`tencentcloud.ssm.v20190923.models.CreateProductSecretRequest`
+        :rtype: :class:`tencentcloud.ssm.v20190923.models.CreateProductSecretResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateProductSecret", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateProductSecretResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateSSHKeyPairSecret(self, request):
+        """创建用于托管SSH密钥对的凭据
+
+        :param request: Request instance for CreateSSHKeyPairSecret.
+        :type request: :class:`tencentcloud.ssm.v20190923.models.CreateSSHKeyPairSecretRequest`
+        :rtype: :class:`tencentcloud.ssm.v20190923.models.CreateSSHKeyPairSecretResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSSHKeyPairSecret", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateSSHKeyPairSecretResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateSecret(self, request):
         """创建新的凭据信息，通过KMS进行加密保护。每个Region最多可创建存储1000个凭据信息。
 
@@ -36,7 +94,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateSecret", params)
+            headers = request.headers
+            body = self.call("CreateSecret", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateSecretResponse()
@@ -64,7 +123,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSecret", params)
+            headers = request.headers
+            body = self.call("DeleteSecret", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSecretResponse()
@@ -84,6 +144,7 @@ class SsmClient(AbstractClient):
 
     def DeleteSecretVersion(self, request):
         """该接口用于直接删除指定凭据下的单个版本凭据，删除操作立即生效，对所有状态下的凭据版本都可以删除。
+        本接口仅适用于用户自定义凭据，本接口不能对云产品凭据进行操作。
 
         :param request: Request instance for DeleteSecretVersion.
         :type request: :class:`tencentcloud.ssm.v20190923.models.DeleteSecretVersionRequest`
@@ -92,7 +153,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSecretVersion", params)
+            headers = request.headers
+            body = self.call("DeleteSecretVersion", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSecretVersionResponse()
@@ -110,6 +172,95 @@ class SsmClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAsyncRequestInfo(self, request):
+        """查询异步任务的执行结果
+
+        :param request: Request instance for DescribeAsyncRequestInfo.
+        :type request: :class:`tencentcloud.ssm.v20190923.models.DescribeAsyncRequestInfoRequest`
+        :rtype: :class:`tencentcloud.ssm.v20190923.models.DescribeAsyncRequestInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAsyncRequestInfo", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAsyncRequestInfoResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeRotationDetail(self, request):
+        """查询凭据轮转策略详情。
+        本接口只适用于云产品凭据。
+
+        :param request: Request instance for DescribeRotationDetail.
+        :type request: :class:`tencentcloud.ssm.v20190923.models.DescribeRotationDetailRequest`
+        :rtype: :class:`tencentcloud.ssm.v20190923.models.DescribeRotationDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeRotationDetail", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeRotationDetailResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeRotationHistory(self, request):
+        """查询凭据轮转历史版本。
+        本接口仅适用于云产品凭据。
+
+        :param request: Request instance for DescribeRotationHistory.
+        :type request: :class:`tencentcloud.ssm.v20190923.models.DescribeRotationHistoryRequest`
+        :rtype: :class:`tencentcloud.ssm.v20190923.models.DescribeRotationHistoryResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeRotationHistory", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeRotationHistoryResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeSecret(self, request):
         """获取凭据的详细属性信息。
 
@@ -120,7 +271,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSecret", params)
+            headers = request.headers
+            body = self.call("DescribeSecret", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSecretResponse()
@@ -138,6 +290,35 @@ class SsmClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeSupportedProducts(self, request):
+        """查询支持的云产品列表
+
+        :param request: Request instance for DescribeSupportedProducts.
+        :type request: :class:`tencentcloud.ssm.v20190923.models.DescribeSupportedProductsRequest`
+        :rtype: :class:`tencentcloud.ssm.v20190923.models.DescribeSupportedProductsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSupportedProducts", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSupportedProductsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DisableSecret(self, request):
         """停用指定的凭据，停用后状态为 Disabled，无法通过接口获取该凭据的明文。
 
@@ -148,7 +329,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DisableSecret", params)
+            headers = request.headers
+            body = self.call("DisableSecret", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DisableSecretResponse()
@@ -176,7 +358,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("EnableSecret", params)
+            headers = request.headers
+            body = self.call("EnableSecret", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.EnableSecretResponse()
@@ -204,7 +387,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetRegions", params)
+            headers = request.headers
+            body = self.call("GetRegions", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetRegionsResponse()
@@ -222,8 +406,38 @@ class SsmClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetSSHKeyPairValue(self, request):
+        """获取SSH密钥对凭据明文信息。
+
+        :param request: Request instance for GetSSHKeyPairValue.
+        :type request: :class:`tencentcloud.ssm.v20190923.models.GetSSHKeyPairValueRequest`
+        :rtype: :class:`tencentcloud.ssm.v20190923.models.GetSSHKeyPairValueResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetSSHKeyPairValue", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetSSHKeyPairValueResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetSecretValue(self, request):
-        """获取指定凭据名称和版本的凭据明文信息，只能获取启用状态的凭据明文。
+        """对于用户自定义凭据，通过指定凭据名称和版本来获取凭据的明文信息；
+        对于云产品凭据如Mysql凭据，通过指定凭据名称和历史版本号来获取历史轮转凭据的明文信息，如果要获取当前正在使用的凭据版本的明文，需要将版本号指定为：SSM_Current。
 
         :param request: Request instance for GetSecretValue.
         :type request: :class:`tencentcloud.ssm.v20190923.models.GetSecretValueRequest`
@@ -232,7 +446,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetSecretValue", params)
+            headers = request.headers
+            body = self.call("GetSecretValue", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetSecretValueResponse()
@@ -260,7 +475,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetServiceStatus", params)
+            headers = request.headers
+            body = self.call("GetServiceStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetServiceStatusResponse()
@@ -288,7 +504,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListSecretVersionIds", params)
+            headers = request.headers
+            body = self.call("ListSecretVersionIds", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListSecretVersionIdsResponse()
@@ -316,7 +533,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListSecrets", params)
+            headers = request.headers
+            body = self.call("ListSecrets", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListSecretsResponse()
@@ -336,6 +554,7 @@ class SsmClient(AbstractClient):
 
     def PutSecretValue(self, request):
         """该接口在指定名称的凭据下增加新版本的凭据内容，一个凭据下最多可以支持10个版本。只能对处于Enabled 和 Disabled 状态的凭据添加新的版本。
+        本接口仅适用于用户自定义凭据，对云产品凭据不能操作。
 
         :param request: Request instance for PutSecretValue.
         :type request: :class:`tencentcloud.ssm.v20190923.models.PutSecretValueRequest`
@@ -344,7 +563,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PutSecretValue", params)
+            headers = request.headers
+            body = self.call("PutSecretValue", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PutSecretValueResponse()
@@ -372,7 +592,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestoreSecret", params)
+            headers = request.headers
+            body = self.call("RestoreSecret", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RestoreSecretResponse()
@@ -390,6 +611,36 @@ class SsmClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RotateProductSecret(self, request):
+        """轮转云产品凭据或云API密钥对凭据。
+        该接口仅适用于处于Enabled状态的云产品凭据或处于Enable状态的云API密钥对凭据，对于其他状态的云产品凭据或云API密钥对凭据或用户自定义凭据不适用。
+
+        :param request: Request instance for RotateProductSecret.
+        :type request: :class:`tencentcloud.ssm.v20190923.models.RotateProductSecretRequest`
+        :rtype: :class:`tencentcloud.ssm.v20190923.models.RotateProductSecretResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RotateProductSecret", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RotateProductSecretResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateDescription(self, request):
         """该接口用于修改指定凭据的描述信息，仅能修改Enabled 和 Disabled 状态的凭据。
 
@@ -400,7 +651,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateDescription", params)
+            headers = request.headers
+            body = self.call("UpdateDescription", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateDescriptionResponse()
@@ -418,8 +670,41 @@ class SsmClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateRotationStatus(self, request):
+        """设置云产品凭据轮转策略，可以设置：
+        是否开启轮转
+        轮转周期
+        轮转开始时间
+
+        :param request: Request instance for UpdateRotationStatus.
+        :type request: :class:`tencentcloud.ssm.v20190923.models.UpdateRotationStatusRequest`
+        :rtype: :class:`tencentcloud.ssm.v20190923.models.UpdateRotationStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateRotationStatus", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateRotationStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateSecret(self, request):
         """该接口用于更新指定凭据名称和版本号的内容，调用该接口会对新的凭据内容加密后覆盖旧的内容。仅允许更新Enabled 和 Disabled 状态的凭据。
+        本接口仅适用于用户自定义凭据，不能对云产品凭据操作。
 
         :param request: Request instance for UpdateSecret.
         :type request: :class:`tencentcloud.ssm.v20190923.models.UpdateSecretRequest`
@@ -428,7 +713,8 @@ class SsmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateSecret", params)
+            headers = request.headers
+            body = self.call("UpdateSecret", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateSecretResponse()
