@@ -26,12 +26,6 @@ FAILEDOPERATION = 'FailedOperation'
 # 证书不存在。
 FAILEDOPERATION_CERTIFICATENOTFOUND = 'FailedOperation.CertificateNotFound'
 
-# 创建日志集失败，请检查日志集名是否已存在。
-FAILEDOPERATION_CREATECLSLOGSETFAILED = 'FailedOperation.CreateClsLogSetFailed'
-
-# 创建日志主题任务失败，请检查日志主题名或任务名是否已存在。
-FAILEDOPERATION_CREATECLSLOGTOPICTASKFAILED = 'FailedOperation.CreateClsLogTopicTaskFailed'
-
 # 站点状态不正确。
 FAILEDOPERATION_INVALIDZONESTATUS = 'FailedOperation.InvalidZoneStatus'
 
@@ -125,6 +119,9 @@ INVALIDPARAMETER_ERRINVALIDACTION = 'InvalidParameter.ErrInvalidAction'
 # 非法操作-非法参数。
 INVALIDPARAMETER_ERRINVALIDACTIONPARAM = 'InvalidParameter.ErrInvalidActionParam'
 
+# 非法操作-非法参数-无效参数值类型。
+INVALIDPARAMETER_ERRINVALIDACTIONPARAMBADVALUETYPE = 'InvalidParameter.ErrInvalidActionParamBadValueType'
+
 # 非法操作-非法参数-参数名重复。
 INVALIDPARAMETER_ERRINVALIDACTIONPARAMDUPLICATENAME = 'InvalidParameter.ErrInvalidActionParamDuplicateName'
 
@@ -140,6 +137,9 @@ INVALIDPARAMETER_ERRINVALIDCONDITIONIGNORECASE = 'InvalidParameter.ErrInvalidCon
 # 非法条件-非法参数名称-匹配类型不支持参数名称。
 INVALIDPARAMETER_ERRINVALIDCONDITIONNAMETARGETNOTSUPPORTNAME = 'InvalidParameter.ErrInvalidConditionNameTargetNotSupportName'
 
+# 非法条件-非法参数值-无效的正则表达式。
+INVALIDPARAMETER_ERRINVALIDCONDITIONVALUEBADREGULAR = 'InvalidParameter.ErrInvalidConditionValueBadRegular'
+
 # 非法条件-非法参数值-无效的参数值。
 INVALIDPARAMETER_ERRINVALIDCONDITIONVALUEBADVALUE = 'InvalidParameter.ErrInvalidConditionValueBadValue'
 
@@ -182,6 +182,9 @@ INVALIDPARAMETER_INVALIDCACHEKEYQUERYSTRINGVALUE = 'InvalidParameter.InvalidCach
 # 无效的节点缓存。
 INVALIDPARAMETER_INVALIDCACHEONLYONSWITCH = 'InvalidParameter.InvalidCacheOnlyOnSwitch'
 
+# 无效的节点缓存时间。
+INVALIDPARAMETER_INVALIDCACHETIME = 'InvalidParameter.InvalidCacheTime'
+
 # 证书信息错误。
 INVALIDPARAMETER_INVALIDCERTINFO = 'InvalidParameter.InvalidCertInfo'
 
@@ -326,6 +329,9 @@ OPERATIONDENIED_L4PROXYINBANNEDSTATUS = 'OperationDenied.L4ProxyInBannedStatus'
 # 绑定4层实例有处于非运行中的状态，禁止操作。
 OPERATIONDENIED_L4STATUSNOTINONLINE = 'OperationDenied.L4StatusNotInOnline'
 
+# 回源白名单已经是最新版本，无需更新。
+OPERATIONDENIED_LATESTVERSIONNOW = 'OperationDenied.LatestVersionNow'
+
 # 已存在多个Cname接入站点，不允许切换至NS。
 OPERATIONDENIED_MULTIPLECNAMEZONE = 'OperationDenied.MultipleCnameZone'
 
@@ -386,9 +392,6 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
-# 无剩余可创建新任务的域名。
-RESOURCEUNAVAILABLE_AVAILABLEDOMAINNOTFOUND = 'ResourceUnavailable.AvailableDomainNotFound'
-
 # 证书不存在或未授权。
 RESOURCEUNAVAILABLE_CERTNOTFOUND = 'ResourceUnavailable.CertNotFound'
 
@@ -416,8 +419,5 @@ UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'
 # 后端服务器发生未知错误。
 UNAUTHORIZEDOPERATION_UNKNOWN = 'UnauthorizedOperation.Unknown'
 
-# 未知参数错误。
-UNKNOWNPARAMETER = 'UnknownParameter'
-
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
